MenuBar Example
===============================================================================

:download:`menu_bar.enaml <../../../examples/widgets/menu_bar.enaml>`

.. literalinclude:: ../../../examples/widgets/menu_bar.enaml
    :language: python

::

 $ enaml-run menu_bar.enaml

.. image:: images/menu_bar.png
